#
# spec file for package brickd
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2019 Frank Kunz
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           brickd
Version:        2.4.3
Release:        bp155.2.13
Summary:        Tinkerforce Brick Daemon
License:        GPL-2.0-only
Group:          System/Daemons
URL:            http://www.tinkerforge.com
Source0:        https://github.com/Tinkerforge/brickd/archive/v%{version}.tar.gz
Source1:        https://github.com/Tinkerforge/daemonlib/archive/brickd-%{version}.tar.gz
Patch0:         harden_brickd-resume.service.patch
Patch1:         harden_brickd.service.patch
BuildRequires:  pkgconfig(libusb)
BuildRequires:  pkgconfig(systemd)
Suggests:       logrotate
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Brick Daemon is a small bridge between the USB port of Bricks and
the TCP/IP socket connection to the language binding APIs.

%prep
%setup -q -a 1 -n %{name}-%{version}
mv daemonlib-%{name}-%{version} src/daemonlib
%patch0 -p1
%patch1 -p1

%build
pushd src/brickd
make %{?_smp_mflags} WITH_SYSTEMD=yes
popd

%install
pushd src/brickd
make install DESTDIR=%{buildroot}
popd
mkdir -p %{buildroot}%{_sbindir}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}-resume

%pre
%service_add_pre brickd-resume.service brickd.service

%post
%service_add_post brickd-resume.service brickd.service

%preun
%service_del_preun brickd-resume.service brickd.service

%postun
%service_del_postun brickd-resume.service brickd.service

%files -n %{name}
%defattr(-,root,root)
%doc src/changelog README.rst
%{_bindir}/*
%{_mandir}/man*/%{name}.*
%config(noreplace) /etc/%{name}.conf
%config /etc/logrotate.d/%{name}
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}-resume.service
%{_sbindir}/rc%{name}
%{_sbindir}/rc%{name}-resume

%changelog
* Wed Aug 25 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Added patch(es):
  * harden_brickd-resume.service.patch
  * harden_brickd.service.patch
* Thu Dec 10 2020 Frank Kunz <mailinglists@kunz-im-inter.net>
- Update to new upstream version 2.4.3:
- Properly shutdown subsystems on Ctrl+C instead of abruptly exiting on Windows
- Rotate persistent log file on Windows and limit its total size to 25 MB
- Add commandline options to override log and config file location on Windows
- Colorize Log Viewer live log messages on Windows
- Reword Log Viewer messages to be less ambiguous on Windows
- Add build option to work without a device file manager such as udevd on Linux
- Allow to handle more then 6 USB devices on Windows
- Use BCM2835 library for SPI connected Bricklets on Raspberry Pi to improve
  performance and work around SPI chip select conflict between Linux kernel 5.4
  and HAT Brick firmware < 2.0.2
- Improve log messages related to HAT (Zero) Brick on Linux
- Fix SPI hardware chip select usage on Linux
- Allow to fully static link brickd for Docker container usage on Linux
- Switch Debian package build to debhelper and drop SysV init support
- Improve USB transfer error logging and stall error recovery
- Fix SPI clock for HAT (Zero) Brick on Linux, if core_freq differs from 250 MHz
- Add config option to override SPI backend detection
* Sun Jan  5 2020 Frank Kunz <mailinglists@kunz-im-inter.net>
- Update to new upstream version 2.4.1:
- Rename bundled libusb to avoid potential collision with system libusb on macOS
- Add missing network dependency to systemd service on Linux
- Make sleep time between SPI reads for HAT (Zero) Brick configurable
- Add experimental support for HAT (Zero) Brick (SPI connected Bricklets) on
  Windows 10 IoT Core, disabled by default due to missing HAT detection
- Notarize Brick Daemon app to make it ready for macOS 10.15
- remove integrated upstream patches
  0001-Makefile-Support-DESTDIR-variable.patch
  0001-use-RPM_OPT_FLAGS-in-rpm-package-builds.patch
  0001-systemd-unit-files-are-always-in-prefix-lib-systemd.patch
* Mon Sep 30 2019 Frank Kunz <frank@kunz-im-inter.net>
- added doc files
* Wed Sep 25 2019 Ludwig Nussel <lnussel@suse.de>
- use download_files in disabled mode to make the package suitable for
  inclusion in the distro
- buildrequire pkgconfig files to OBS chooses the right package
- backport DESTDIR support (0001-Makefile-Support-DESTDIR-variable.patch)
- use optflags for compiling
  (0001-use-RPM_OPT_FLAGS-in-rpm-package-builds.patch)
- fix path of systemd unit files in the Makefile already
  (0001-systemd-unit-files-are-always-in-prefix-lib-systemd.patch)
* Mon Sep 23 2019 Frank Kunz <frank@kunz-im-inter.net>
- release 2.4.0
